import {Component} from '@angular/core'
import {Material} from '../../../../shared/model/material.model'
import {MaterialService} from '../../../../material/service/material.service'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorHandlingComponent} from '../../../../shared/components/subscribing.component'
import {MixService} from '../../../services/mix.service'
import {ErrorService} from '../../../../shared/service/error.service'
import {Recipe} from "../../../../shared/model/recipe.model";
import {RecipeService} from "../../../services/recipe.service";

@Component({
  selector: 'cre-mix-add',
  templateUrl: './mix-add.component.html',
  styleUrls: ['./mix-add.component.sass']
})
export class MixAddComponent extends ErrorHandlingComponent {
  materials: Material[] | null = [new Material(0, "Example", 1000, null, null)]
  recipe: Recipe | null

  private recipeId: number | null

  constructor(
    private recipeService: RecipeService,
    private materialService: MaterialService,
    private mixService: MixService,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    super.ngOnInit()

    this.recipeId = this.urlUtils.parseIntUrlParam('recipeId')
    this.fetchRecipe()
    // this.fetchMaterials()
  }

  private fetchRecipe() {
    this.subscribe(
      this.recipeService.getById(this.recipeId),
      recipe => this.recipe = recipe
    )
  }

  private fetchMaterials() {
    this.subscribe(
      this.materialService.getAllForMixCreation(this.recipeId),
      materials => this.materials = materials
    )
  }

  submit(values) {
    this.subscribeAndNavigate(
      this.mixService.saveWithUnits(values.name, values.recipeId, values.materialTypeId, values.mixMaterials, values.units),
      `/color/edit/${this.recipeId}`
    )
  }
}
